@@ -15,8 +15,10 @@
 
 from __future__ import annotations
 
+import orjson as json
 from tornado.web import RedirectHandler
 
+from .. import ORJSON_OPTIONS
 from ..utils.request_handler import APIRequestHandler, HTMLRequestHandler
 from ..utils.utils import ModuleInfo, name_to_id
 
@@ -52,22 +54,22 @@ class Endpoints(HTMLRequestHandler):
 
     def get_endpoints(
         self,
-    ) -> list[dict[str, str | list[dict[str, str | int | list[str]]]]]:
+    ) -> list[dict[str, str | list[dict[str, str | list[str]]]]]:
         """Get a list of all API endpoints and return it."""
-        endpoints: list[
-            dict[str, str | list[dict[str, str | int | list[str]]]]
-        ] = []
+        endpoints: list[dict[str, str | list[dict[str, str | list[str]]]]] = []
         for module_info in self.settings["MODULE_INFOS"]:
-            api_paths: list[dict[str, str | int | list[str]]] = [
+            api_paths: list[dict[str, str | list[str]]] = [
                 {
                     "path": handler[0],
                     "methods": handler[1].get_allowed_methods(),
+                    "content_types": list(handler[1].POSSIBLE_CONTENT_TYPES),
                 }
                 for handler in module_info.handlers
                 if handler[0].startswith("/api/")
+                if issubclass(handler[1], APIRequestHandler)
                 if (
-                    issubclass(handler[1], APIRequestHandler)
-                    and self.is_authorized(handler[1].REQUIRED_PERMISSION)
+                    handler[1].REQUIRED_PERMISSION is None
+                    or self.is_authorized(handler[1].REQUIRED_PERMISSION)
                 )
             ]
             if len(api_paths) > 0:
@@ -84,6 +86,18 @@ class Endpoints(HTMLRequestHandler):
 class EndpointsAPI(APIRequestHandler, Endpoints):
     """Show a list of all API endpoints."""
 
+    POSSIBLE_CONTENT_TYPES: tuple[
+        str, ...
+    ] = APIRequestHandler.POSSIBLE_CONTENT_TYPES + ("application/x-ndjson",)
+
     async def get(self, *, head: bool = False) -> None:
         """Handle a GET request."""
-        return await self.finish(self.dump(self.get_endpoints()))
+        if self.content_type == "application/x-ndjson":
+            await self.finish(
+                b"\n".join(
+                    json.dumps(endpoint, option=ORJSON_OPTIONS)
+                    for endpoint in self.get_endpoints()
+                )
+            )
+        else:
+            await self.finish(self.dump(self.get_endpoints()))
