@@ -16,6 +16,7 @@
 from __future__ import annotations
 
 import asyncio
+import contextlib
 import logging
 import os
 import random
@@ -27,15 +28,15 @@ from datetime import date, datetime
 from multiprocessing import Value
 from typing import Any, Literal, cast
 
-import elasticapm  # type: ignore
+import elasticapm  # type: ignore[import]
 import orjson as json
 from redis.asyncio import Redis
 from tornado.httpclient import AsyncHTTPClient
 from tornado.web import Application, HTTPError
-from UltraDict import UltraDict  # type: ignore
+from UltraDict import UltraDict  # type: ignore[import]
 
 from .. import DIR as ROOT_DIR
-from .. import EVENT_REDIS, ORJSON_OPTIONS
+from .. import EVENT_REDIS, ORJSON_OPTIONS, pytest_is_running
 from ..utils.request_handler import HTMLRequestHandler
 from ..utils.utils import emojify
 
@@ -62,15 +63,15 @@ class QuotesObjBase:
     __slots__ = ("id",)
     id: int  # pylint: disable=invalid-name
 
+    async def fetch_new_data(self) -> QuotesObjBase:
+        """Fetch new data from the API."""
+        raise NotImplementedError
+
     # pylint: disable=unused-argument
     def get_id_as_str(self, minify: bool = False) -> str:
         """Get the id of the object as a string."""
         return str(self.id)
 
-    async def fetch_new_data(self) -> QuotesObjBase:
-        """Fetch new data from the API."""
-        raise NotImplementedError
-
 
 @dataclass
 class Author(QuotesObjBase):
@@ -81,13 +82,13 @@ class Author(QuotesObjBase):
     # tuple(url_to_info, info_str, creation_date)
     info: None | tuple[str, None | str, date]
 
-    def update_name(self, name: str) -> None:
-        """Update author data with another author."""
-        name = fix_author_name(name)
-        if self.name != name:
-            # name changed -> info should change too
-            self.info = None
-            self.name = name
+    def __str__(self) -> str:
+        """Return the name of the author."""
+        return (
+            emojify(self.name.strip())
+            if (now := datetime.utcnow()).day == 1 and now.month == 4
+            else self.name.strip()
+        )
 
     async def fetch_new_data(self) -> Author:
         """Fetch new data from the API."""
@@ -108,13 +109,13 @@ class Author(QuotesObjBase):
             else None,
         }
 
-    def __str__(self) -> str:
-        """Return the name of the author."""
-        return (
-            emojify(self.name.strip())
-            if (now := datetime.utcnow()).day == 1 and now.month == 4
-            else self.name.strip()
-        )
+    def update_name(self, name: str) -> None:
+        """Update author data with another author."""
+        name = fix_author_name(name)
+        if self.name != name:
+            # name changed -> info should change too
+            self.info = None
+            self.name = name
 
 
 @dataclass
@@ -125,15 +126,13 @@ class Quote(QuotesObjBase):
     quote: str
     author: Author
 
-    def update_quote(
-        self, quote: str, author_id: int, author_name: str
-    ) -> None:
-        """Update quote data with new data."""
-        self.quote = fix_quote_str(quote)
-        if self.author.id == author_id:
-            self.author.update_name(author_name)
-            return
-        self.author = get_author_updated_with(author_id, author_name)
+    def __str__(self) -> str:
+        """Return the content of the quote."""
+        return (
+            emojify(self.quote.strip())
+            if (now := datetime.utcnow()).day == 1 and now.month == 4
+            else self.quote.strip()
+        )
 
     async def fetch_new_data(self) -> Quote:
         """Fetch new data from the API."""
@@ -148,13 +147,15 @@ class Quote(QuotesObjBase):
             "path": f"/zitate/info/z/{self.id}",
         }
 
-    def __str__(self) -> str:
-        """Return the content of the quote."""
-        return (
-            emojify(self.quote.strip())
-            if (now := datetime.utcnow()).day == 1 and now.month == 4
-            else self.quote.strip()
-        )
+    def update_quote(
+        self, quote: str, author_id: int, author_name: str
+    ) -> None:
+        """Update quote data with new data."""
+        self.quote = fix_quote_str(quote)
+        if self.author.id == author_id:
+            self.author.update_name(author_name)
+            return
+        self.author = get_author_updated_with(author_id, author_name)
 
 
 @dataclass
@@ -166,6 +167,29 @@ class WrongQuote(QuotesObjBase):
     author: Author
     rating: int
 
+    def __str__(self) -> str:
+        r"""
+        Return the wrong quote.
+
+        like: '»quote« - author'.
+        """
+        return f"»{self.quote}« - {self.author}"
+
+    async def fetch_new_data(self) -> WrongQuote:
+        """Fetch new data from the API."""
+        if self.id == -1:
+            api_data = await make_api_request(
+                "wrongquotes",
+                f"quote={self.quote.id}&author={self.author.id}&simulate=true",
+            )
+            if api_data:
+                api_data = api_data[0]
+        else:
+            api_data = await make_api_request(f"wrongquotes/{self.id}")
+        if not api_data:
+            return self
+        return parse_wrong_quote(api_data, self)
+
     def get_id(self) -> tuple[int, int]:
         """
         Get the id of the quote and the author in a tuple.
@@ -184,20 +208,15 @@ class WrongQuote(QuotesObjBase):
             return str(self.id)
         return f"{self.quote.id}-{self.author.id}"
 
-    async def fetch_new_data(self) -> WrongQuote:
-        """Fetch new data from the API."""
-        if self.id == -1:
-            api_data = await make_api_request(
-                "wrongquotes",
-                f"quote={self.quote.id}&author={self.author.id}&simulate=true",
-            )
-            if api_data:
-                api_data = api_data[0]
-        else:
-            api_data = await make_api_request(f"wrongquotes/{self.id}")
-        if not api_data:
-            return self
-        return parse_wrong_quote(api_data, self)
+    def to_json(self) -> dict[str, Any]:
+        """Get the wrong quote as JSON."""
+        return {
+            "id": self.get_id_as_str(),
+            "quote": self.quote.to_json(),
+            "author": self.author.to_json(),
+            "rating": self.rating,
+            "path": f"/zitate/{self.get_id_as_str()}",
+        }
 
     async def vote(
         # pylint: disable=unused-argument
@@ -225,24 +244,6 @@ class WrongQuote(QuotesObjBase):
             self,
         )
 
-    def to_json(self) -> dict[str, Any]:
-        """Get the wrong quote as JSON."""
-        return {
-            "id": self.get_id_as_str(),
-            "quote": self.quote.to_json(),
-            "author": self.author.to_json(),
-            "rating": self.rating,
-            "path": f"/zitate/{self.get_id_as_str()}",
-        }
-
-    def __str__(self) -> str:
-        r"""
-        Return the wrong quote.
-
-        like: '»quote« - author'.
-        """
-        return f"»{self.quote}« - {self.author}"
-
 
 def get_wrong_quotes(
     filter_fun: None | Callable[[WrongQuote], bool] = None,
@@ -304,6 +305,8 @@ async def make_api_request(
     body: None | str = None,
 ) -> Any:  # list[dict[str, Any]] | dict[str, Any]:
     """Make API request and return the result as dict."""
+    if pytest_is_running():
+        return None
     response = await AsyncHTTPClient().fetch(
         f"{API_URL}/{endpoint}?{args}",
         method=method,
@@ -313,13 +316,11 @@ async def make_api_request(
         ca_certs=os.path.join(ROOT_DIR, "ca-bundle.crt"),
     )
     if response.code != 200:
-        logger.error(
-            "%s request to '%s/%s?%s' with body='%s' "
-            "failed with code=%d and reason='%s'",
+        logger.warning(
+            "%s request to %r with body=%r "
+            "failed with code=%d and reason=%r",
             method,
-            API_URL,
-            endpoint,
-            args,
+            f"{API_URL}/{endpoint}?{args}",
             body,
             response.code,
             response.reason,
@@ -446,11 +447,9 @@ def parse_list_of_quote_data(
 
 async def update_cache_periodically(app: Application) -> None:  # noqa: C901
     """Start updating the cache every hour."""
-    # pylint: disable=too-complex, too-many-branches
-    try:
+    # pylint: disable=too-complex
+    with contextlib.suppress(asyncio.TimeoutError):
         await asyncio.wait_for(EVENT_REDIS.wait(), 5)
-    except asyncio.TimeoutError:
-        pass
     redis: Redis[str] = cast("Redis[str]", app.settings.get("REDIS"))
     prefix: str = app.settings.get("REDIS_PREFIX", "")
     apm: None | elasticapm.Client
@@ -483,35 +482,35 @@ async def update_cache_periodically(app: Application) -> None:  # noqa: C901
                             await update_cache(
                                 app, update_quotes=False, update_authors=False
                             )
-                        except Exception as exc:  # pylint: disable=broad-except
-                            logger.exception(exc)
-                            logger.error("Updating quotes cache failed.")
-                            apm = app.settings.get("ELASTIC_APM_CLIENT")
+                        except Exception:  # pylint: disable=broad-except
+                            logger.exception("Updating quotes cache failed")
+                            apm = app.settings.get("ELASTIC_APM", {}).get(
+                                "CLIENT"
+                            )
                             if apm:
                                 apm.capture_exception()
                         else:
-                            logger.info("Updated quotes cache successfully.")
+                            logger.info("Updated quotes cache successfully")
                     logger.info(
                         "Next update of quotes cache in %d seconds",
                         update_cache_in,
                     )
                     await asyncio.sleep(update_cache_in)
 
+    # update the cache every hour
     failed = 0
-    # pylint: disable=while-used
-    while True:  # update the cache every hour
+    while True:  # pylint: disable=while-used
         try:
             await update_cache(app)
-        except Exception as exc:  # pylint: disable=broad-except
-            logger.exception(exc)
-            logger.error("Updating quotes cache failed.")
-            apm = app.settings.get("ELASTIC_APM_CLIENT")
+        except Exception:  # pylint: disable=broad-except
+            logger.exception("Updating quotes cache failed")
+            apm = app.settings.get("ELASTIC_APM", {}).get("CLIENT")
             if apm:
                 apm.capture_exception()
             failed += 1
             await asyncio.sleep(pow(min(failed * 2, 60), 2))  # 4,16,...,60*60
         else:
-            logger.info("Updated quotes cache successfully.")
+            logger.info("Updated quotes cache successfully")
             failed = 0
             await asyncio.sleep(60 * 60)
 
@@ -523,7 +522,7 @@ async def update_cache(
     update_authors: bool = True,
 ) -> None:
     """Fill the cache with all data from the API."""
-    logger.info("Updating quotes cache...")
+    logger.info("Updating quotes cache")
     redis: Redis[str] = cast("Redis[str]", app.settings.get("REDIS"))
     prefix: str = app.settings.get("REDIS_PREFIX", "")
     redis_available = EVENT_REDIS.is_set()
@@ -627,12 +626,12 @@ async def get_rating_by_id(quote_id: int, author_id: int) -> int:
 
 def get_random_quote_id() -> int:
     """Get random quote id."""
-    return random.randint(1, MAX_QUOTES_ID.value)
+    return random.randint(1, MAX_QUOTES_ID.value)  # nosec: B311
 
 
 def get_random_author_id() -> int:
     """Get random author id."""
-    return random.randint(1, MAX_AUTHORS_ID.value)
+    return random.randint(1, MAX_AUTHORS_ID.value)  # nosec: B311
 
 
 def get_random_id() -> tuple[int, int]:
@@ -682,7 +681,7 @@ class QuoteReadyCheckHandler(HTMLRequestHandler):
             self.set_header("Retry-After", "5")
             raise HTTPError(503, reason="Service available in a few seconds")
 
-    async def prepare(self) -> None:
+    async def prepare(self) -> None:  # noqa: D102
         await super().prepare()
         if self.request.method != "OPTIONS":
             await self.check_ready()
