@@ -62,21 +62,9 @@ SERVICES: tuple[Service, ...] = (
         "online.",
         {
             "Name": "Das Asoziale Netzwerk",
-            "Domain": "stk.asozial.org",
             "SuperTuxKart-Download": "https://supertuxkart.net/Download",
         },
     ),
-    Service(
-        "Matrix-Heimserver",
-        "Der Matrix-Heimserver des Asozialen Netzwerks ist zuverlässig und "
-        "nutzt im Gegensatz zu den meisten anderen Servern Dendrite anstatt "
-        "Synapse. Die Erstellung eines Accounts ist 100 % kostenlos und ohne "
-        "E-Mail-Adresse oder Telefonnummer möglich.",
-        {
-            "Domain": "asozial.org",
-            "Matrix-Client": "https://chat.asozial.org",
-        },
-    ),
     Service(
         "Syncplay-Server",
         "Mit dem Syncplay-Server des Asozialen Netzwerks kann man Online "
@@ -86,6 +74,25 @@ SERVICES: tuple[Service, ...] = (
             "Installations-Guide": "https://syncplay.pl/guide/install",
         },
     ),
+    Service(
+        "Matrix-Heimserver",
+        "Der Matrix-Heimserver des Asozialen Netzwerks ist zuverlässig und "
+        "nutzt im Gegensatz zu den meisten anderen Servern Dendrite anstatt "
+        "Synapse. Die Erstellung eines Accounts ist 100% kostenlos und ohne "
+        "E-Mail-Adresse oder Telefonnummer möglich.",
+        {
+            "Domain": "asozial.org",
+            "Matrix-Client": "https://chat.asozial.org",
+        },
+    ),
+    Service(
+        "XMPP-Server",
+        "Das Asoziale Netzwerk hat auch einen XMPP-Server.",
+        {
+            "Domain": "asozial.org",
+            "Software": "ejabberd",
+        },
+    ),
 )
 
 
