@@ -25,7 +25,7 @@ from typing import Any, cast
 
 import defity
 import tornado.web
-from blake3 import blake3  # type: ignore
+from blake3 import blake3  # type: ignore[import]
 
 from .. import DIR as ROOT_DIR
 from .. import STATIC_DIR
@@ -45,7 +45,7 @@ def create_file_hashes_dict() -> dict[str, str]:
     return {
         str(path).removeprefix(ROOT_DIR): hash_file(path)
         for path in Path(STATIC_DIR).rglob("*")
-        if path.is_file()
+        if path.is_file() and "img/openmoji-svg-" not in str(path)
     }
 
 
@@ -141,20 +141,10 @@ def get_handlers() -> list[Handler]:
     """Return a list of handlers for static files."""
     handlers: list[Handler] = [
         (
-            r"/(?:static/)?(robots\.txt|\.env)",
+            r"/(?:static/)?(\.env|favicon\.png|humans\.txt|robots\.txt)",
             StaticFileHandler,
             {"path": STATIC_DIR},
         ),
-        (
-            r"/(?:static/)?(humans\.txt)",
-            StaticFileHandler,
-            {"path": STATIC_DIR},
-        ),
-        (
-            r"/(?:static/)?(favicon\.ico)",
-            CachedStaticFileHandler,
-            {"path": STATIC_DIR},
-        ),
     ]
     if sys.flags.dev_mode:
         # add handlers for the not minified CSS files
@@ -197,10 +187,12 @@ def fix_static_url(url: str) -> str:
         url = f"/static/{url}"
     if "?" in url:
         url = url.split("?")[0]
+    if url.startswith("/static/img/openmoji-svg-"):
+        return url
     if url in FILE_HASHES_DICT:
         hash_ = FILE_HASHES_DICT[url]
-        if url == "/static/favicon.ico":
-            return f"/favicon.ico?v={hash_}"
+        if url == "/static/favicon.png":
+            return f"/favicon.png?v={hash_}"
         return f"{url}?v={hash_}"
     logger.warning("%s not in FILE_HASHES_DICT", url)
     return url
@@ -211,9 +203,15 @@ class StaticFileHandler(tornado.web.StaticFileHandler):
 
     content_type: None | str
 
-    def data_received(self, chunk: bytes) -> None | Awaitable[None]:
+    def data_received(  # noqa: D102
+        self, chunk: bytes
+    ) -> None | Awaitable[None]:
         pass
 
+    def head(self, path: str) -> Awaitable[None]:
+        """Handle HEAD requests."""
+        return self.get(path)
+
     def initialize(
         self,
         path: str,
@@ -224,21 +222,6 @@ class StaticFileHandler(tornado.web.StaticFileHandler):
         super().initialize(path=path, default_filename=default_filename)
         self.content_type = content_type
 
-    def head(self, path: str) -> Awaitable[None]:
-        """Handle HEAD requests."""
-        return self.get(path)
-
-    def validate_absolute_path(
-        self, root: str, absolute_path: str
-    ) -> None | str:
-        """Validate the path and detect the content type."""
-        if path := super().validate_absolute_path(root, absolute_path):
-            if not self.content_type:
-                self.content_type = CONTENT_TYPES.get(path.rsplit(".", 1)[-1])
-                if not self.content_type:
-                    self.content_type = defity.from_file(path)
-        return path
-
     def set_extra_headers(self, _: str) -> None:
         """Reset the Content-Type header if we know it better."""
         if self.content_type:
@@ -249,11 +232,29 @@ class StaticFileHandler(tornado.web.StaticFileHandler):
             else:
                 self.set_header("Content-Type", self.content_type)
 
+    def validate_absolute_path(
+        self, root: str, absolute_path: str
+    ) -> None | str:
+        """Validate the path and detect the content type."""
+        if (
+            path := super().validate_absolute_path(root, absolute_path)
+        ) and not self.content_type:
+            self.content_type = CONTENT_TYPES.get(path.rsplit(".", 1)[-1])
+            if not self.content_type:
+                self.content_type = defity.from_file(path)
+        return path
+
 
 class CachedStaticFileHandler(StaticFileHandler):
     """A static file handler that sets a smarter Cache-Control header."""
 
-    def data_received(self, chunk: bytes) -> None | Awaitable[None]:
+    def compute_etag(self) -> None | str:
+        """Don't compute ETag, because it isn't necessary."""
+        return None
+
+    def data_received(  # noqa: D102
+        self, chunk: bytes
+    ) -> None | Awaitable[None]:
         pass
 
     @classmethod
@@ -266,12 +267,12 @@ class CachedStaticFileHandler(StaticFileHandler):
     def set_headers(self) -> None:
         """Set the default headers for this handler."""
         super().set_headers()
-        if not sys.flags.dev_mode and "v" in self.request.arguments:
+        if not sys.flags.dev_mode and (
+            "v" in self.request.arguments
+            # guaranteed uniqueness is done via the 14.0 in the folder name
+            or self.path.startswith("/static/img/openmoji-svg-")
+        ):
             self.set_header(  # never changes
                 "Cache-Control",
-                f"public, immutable, min-fresh={10 * 365 * 24 * 60 * 60}",
+                f"public, immutable, min-fresh={60 * 60 * 24 * 365 * 10}",
             )
-
-    def compute_etag(self) -> None | str:
-        """Don't compute etag, because it isn't necessary."""
-        return None
